<?php

date_default_timezone_set("America/Sao_Paulo");

class ForecastIO
{
	private $key = "???";
	private $area = "-22.8,-47.0"; // latitude/longitude
	private $current;
	private $nextHour;
	private $sixOclock;
	private $loaded = false;

	public static function toCelsius($t)
	{
		return round((5/9)*($t-32));
	}
	
	public function retrieveInfo()
	{
		$data = file_get_contents("https://api.forecast.io/forecast/".$this->key."/".$this->area);
		if ($data)
		{
			$json = json_decode($data);


			$dt = strtotime(date("Y-m-d H").":00:00");

			$offset = $json->currently->time - $dt;

			$this->current = array("icon"=>$json->currently->icon, "temperature" => ForecastIO::toCelsius($json->currently->temperature));
			$nextHour = $json->currently->time - $offset + 3600;
			$diff2six = 18 - date("H");
			if ($diff2six>1)
			{
				$sixOclock = $json->currently->time - $offset + (3600 * $diff2six);
			}
			else
				$sixOclock = -1;

			foreach($json->hourly->data as $item)
				if ($item->time == $nextHour)
					$this->nextHour = array("icon" => $item->icon, "temperature" => ForecastIO::toCelsius($item->temperature));
				elseif ($item->time == $sixOclock)
					$this->sixOclock = array("icon" => $item->icon, "temperature" => ForecastIO::toCelsius($item->temperature));
			
			$this->loaded = true;
			return true;
		}
		return false;
	}

	public function getCurrent()
	{
		return $this->current;
	}

	public function getNextHour()
	{
		return $this->nextHour;
	}

	public function getSixOClock()
	{
		return $this->sixOclock;
	}

	public function isSunny($which)
	{
		//possibles: clear-day, clear-night, rain, snow, sleet, wind, fog, cloudy, partly-cloudy-day, or partly-cloudy-night
		return in_array($which, array("clear-day", "clear-night", "wind", "fog", "cloudy", "partly-cloudy-day", "partly-cloudy-night"));
	}

	public function isRaining($which)
	{
		return !$this->isSunny($which);
	}

}

?>
